@@ -11,4 +11,6 @@ import sys
 #                   ]:
 #     sys.path.append(path_name)
 
-from .features_for_any_graph import FeatureCalculator
\ No newline at end of file
+from .features_for_any_graph import FeatureCalculator
+from .features_meta import features_meta
+from .features_meta import accelerated_features_meta
